% MATLAB script that produces the results for the following article "Cycling Skill Inventory: Assessment of motor-tactical skills and safety-motives"
% by J. C. F. de Winter, N. Kovcsov, and M. Hagenzieker 
% Published in Traffic Injury Prevention

clear all;close all;clc %#ok<CLALL>
%%
lding_Kovacsova_2016=[0.528	-0.383 % loadings from Kovcsova, N., De Winter, J. C. F., Schwab, A. L., Christoph, M., Twisk, D. A. M., & Hagenzieker, M. P. (2016). Riding performance on a conventional bicycle and a pedelec in low speed exercises: Objective and subjective evaluation of middle-aged and older persons. Transportation Research Part F: Traffic Psychology and Behaviour, 42, 2843.
    0.758	-0.184
    -0.112	0.572
    0.502	0.079
    0.816	0.149
    0.328	0.627
    0.806	0.190
    0.547	0.165
    0.839	-0.03
    0.879	0.019
    0.462	0.260
    0.200	0.660
    0.127	0.682
    0.749	0.053
    0.821	-0.163
    0.010	0.901
    0.679	0.143];
lding_Kovacsova_2016=[lding_Kovacsova_2016(:,2) lding_Kovacsova_2016(:,1)];
[X,~,raw]=xlsread('CSI_data.xlsx','A2:AV1139');
%%
disp(['Number of respondents = ' num2str(size(X,1))])
disp(['Number of respondents from CrowdFlower = ' num2str(sum(strcmp(raw(:,2),'Crowdflower1'))+sum(strcmp(raw(:,2),'Crowdflower2')))])
disp(['Number of respondents from Facebook = ' num2str(sum(strcmp(raw(:,2),'facebook')))])
disp(['Number of respondents from paper-and-pencil questionnaires = ' num2str(sum(strcmp(raw(:,2),'SWOVtraining'))+sum(strcmp(raw(:,2),'TUfidelity'))++sum(strcmp(raw(:,2),'TUtraining')))])
disp(['Number of respondents from paper-and-pencil questionnaires in Dutch = ' num2str(sum(strcmp(raw(:,2),'SWOVtraining')))])
UC=unique(raw(:,5));UCn=NaN(length(UC),1);for i=1:length(UC);UCn(i)=sum(strcmp(raw(:,5),UC(i)));end
temp=find(UCn>50);
for i=1:length(temp)
    disp(['Number of respondents from ' char(UC(temp(i))) ' = ' num2str(UCn(temp(i)))])
end
disp(['Gender available, n = ' num2str(sum(~isnan(X(:,3))))])
disp(['Gender unavailable, n = ' num2str(sum(isnan(X(:,3))))])
disp(['Percentage males = ' sprintf('%1.1f',100*(nanmean(X(:,3))-1)) '%'])
disp(['Age available, n = ' num2str(sum(~isnan(X(:,4))))])
disp(['Age unavailable, n = ' num2str(sum(isnan(X(:,4))))])
disp(['Mean age = ' sprintf('%1.1f',mean(X(:,4)))])
disp(['SD age = ' sprintf('%1.1f',std(X(:,4)))])
disp(['Cycling km available, n = ' num2str(sum(~isnan(X(:,8))))])
disp(['Cycling km unavailable, n = ' num2str(sum(isnan(X(:,8))))])
disp(['Mean cycling km = ' sprintf('%1.2f',nanmean(X(:,8)))])
disp(['SD cycling = ' sprintf('%1.2f',nanstd(X(:,8)))])
disp(['Cycling frequency available, n = ' num2str(sum(~isnan(X(:,9))))])
disp(['Cycling frequency unavailable, n = ' num2str(sum(isnan(X(:,9))))])
disp(['Mean cycling frequency = ' sprintf('%1.2f',nanmean(X(:,9)))])
disp(['SD cycling frequency = ' sprintf('%1.2f',nanstd(X(:,9)))])
disp(['Accidents available, n = ' num2str(sum(~isnan(X(:,37))))])
disp(['Accidents unavailable, n = ' num2str(sum(isnan(X(:,37))))])
disp(['Mean accidents = ' sprintf('%1.2f',nanmean(X(:,37)))])
disp(['SD accidents = ' sprintf('%1.2f',nanstd(X(:,37)))])
disp(['% reporting at least 1 accident = ' sprintf('%1.1f',100*nansum(X(:,37)>0)./nansum(X(:,37)>-1))])
RA=find(X(:,37)>0); % index of respondents reporting an accident
RAc=find(X(:,37)>0 & nansum(X(:,[38:43 45]),2)); % index of respondents reporting an accident and a reason for that accident
disp(['Any response (except I prefer not to respond) % = ' sprintf('%1.1f',100*length(RAc)/length(RA))])
disp(['Fall from bicycle % = ' sprintf('%1.1f',100*nansum(X(RAc,38))./size(RAc,1))])
disp(['Collision with a pedestrian % = ' sprintf('%1.1f',100*nansum(X(RAc,39))./size(RAc,1))])
disp(['Collision with a motor vehicle (car, truck, etc.) % = ' sprintf('%1.1f',100*nansum(X(RAc,40))./size(RAc,1))])
disp(['Collision with another cyclist % = ' sprintf('%1.1f',100*nansum(X(RAc,41))./size(RAc,1))])
disp(['Collision with a motorbike / moped % = ' sprintf('%1.1f',100*nansum(X(RAc,42))./size(RAc,1))])
disp(['Collision with obstacle (curb, pole, etc.) % = ' sprintf('%1.1f',100*nansum(X(RAc,43))./size(RAc,1))])
disp(['I prefer not to respond % = ' sprintf('%1.1f',100*nansum(X(RAc,44))./size(RAc,1))])
disp(['Other % = ' sprintf('%1.1f',100*nansum(X(RAc,45))./size(RAc,1))])
%% Scree plot
CSI=X(:,20:36);
CSI2=knnimpute(CSI); % replace NaNs with value from nearest-neighbor variable (column) for that participant (i.e., look for which variable is most similar) (only applies to 0.026% of the data)
r=corr(CSI2);
eigr=sort(eig(r),'descend');
varexplained=100*(eigr./sum(eigr));
figure('name','Figure 2. Scree plot','numbertitle','off');hold on
plot(eigr,'k-o','Linewidth',3,'markersize',20)
ylabel('Eigenvalue');xlabel('Component number')
for i=1:4;text(i+0.13,eigr(i)+0.2,[sprintf('%0.1f',varexplained(i)) '%'],'color','b','fontsize',20);end % show variance explained in text
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',20)
set(gca,'LooseInset', [0.01 0.01 0.01 0.01],'xtick',1:1:100,'xlim',[.5  length(r)+.5])
%% Perform PCA and show loadings
lding=pca(r,2);
[lding_promax]=rotatefactors(lding,'method','promax');
for i=1:size(lding_promax,2);if mean(lding_promax(:,i))<0;lding_promax(:,i)=-lding_promax(:,i);end;end

disp('Tuckers congruence coefficient  between the obliquely rotated component loadings shown in Table 2 and the obliquely rotated factor loadings in Kovcsov et al. (2016)')
disp(CC(lding_promax,lding_Kovacsova_2016))

[lding_varimax,T]=rotatefactors(lding,'method','varimax');
for i=1:size(lding_varimax,2);if mean(lding_varimax(:,i))<0;lding_varimax(:,i)=-lding_varimax(:,i);end;end

pc_scores_promax = zscore(CSI2)/lding_promax';
pc_scores_varimax = zscore(CSI2)/lding_varimax';

disp('Correlation between safety-motives score and motor-tactical-skills score (Promax rotated)')
disp(corr(pc_scores_promax(:,1),pc_scores_promax(:,2)))
disp('Correlation between safety-motives score and motor-tactical-skills score (Varimax rotated)')
disp(corr(pc_scores_varimax(:,1),pc_scores_varimax(:,2)))
disp('Principal component loadings after oblique (Promax) and orthogonal (Varimax) rotation')
disp(round([lding_promax lding_varimax],2))
disp('Item numbers of items loading on both components')
disp(find(lding_promax(:,1)>.20 & lding_promax(:,2)>.20)')
% https://stats.stackexchange.com/questions/126885/methods-to-compute-factor-scores-and-what-is-the-score-coefficient-matrix-in
%% Means, standard deviations, and correlation matrix of the CSI scores
disp(round([nanmean(CSI)' nanstd(CSI)' r],2))
%% Correlations between component scores and criterion variables
c_promax=corr([pc_scores_promax X(:,[3 4 8 9 37])],'rows','pairwise');
disp('Bivariate Pearson product-moment correlation coefficients between the obliquely-rotated component scores of the Cycling Skill Inventory, Gender, Age, Cycling km, Cycling frequency, and Accidents 3Y:')
disp(round(c_promax,2))
c_varimax=corr([pc_scores_varimax X(:,[3 4 8 9 37])],'rows','pairwise');
disp('Bivariate Pearson product-moment correlation coefficients between the orthogonally-rotated component scores of the Cycling Skill Inventory, Gender, Age, Cycling km, Cycling frequency, and Accidents 3Y:')
disp(round(c_varimax,2))
%%
% 1. safety skills/motives
% 2. motor-tactical skills
% 3. Gender (1 = female, 2 = male)
% 4. Age
% 8. Cycling km
% 9. Cycling frequency
% 37. Accidents
%%
InExpF=find(X(:,8)<nanmedian(X(:,8)) & X(:,3)==1); % 0-10 km of cycling and female
InExpM=find(X(:,8)<nanmedian(X(:,8)) & X(:,3)==2); % 0-10 km of cycling and male
ExpF=find(X(:,8)>nanmedian(X(:,8)) & X(:,3)==1);   % 31 or more km of cycling and female
ExpM=find(X(:,8)>nanmedian(X(:,8)) & X(:,3)==2);   % 31 of more km of cycling and male
F=[mean(pc_scores_varimax(InExpF,:))
    mean(pc_scores_varimax(InExpM,:))
    mean(pc_scores_varimax(ExpF,:))
    mean(pc_scores_varimax(ExpM,:))];
SEM=[std(pc_scores_varimax(InExpF,:))./sqrt(length(InExpF))
    std(pc_scores_varimax(InExpM,:))./sqrt(length(InExpM))
    std(pc_scores_varimax(ExpF,:))./sqrt(length(ExpF))
    std(pc_scores_varimax(ExpM,:))./sqrt(length(ExpM))];
%% DSI skills score vs. DSI safety-motives score (Lajunen & Summala, 1995)
FDSI=[1.720710974             -2.359317422
    -0.37187017               -2.132660582
    -3.1                       3.106525313
    -1.897140649               6.482226884];

SEMDSI=[1.723949515	2.026645501
    4.932122518	5.166619423
    3.610820379	3.149951811
    3.908650146	4.150008504];

SEMDSI=abs(SEMDSI)/2;

figure;hold on;
plot([-10 10],[0 0],':','Linewidth',1,'color',[.5 .5 .5])
plot([0 0],[-10 10],':','Linewidth',1,'color',[.5 .5 .5])

text(FDSI(1,1)+0.45,FDSI(1,2)-0.5,'Inexperienced females','color',[.5 .5 .5])
plot(FDSI(1,1),FDSI(1,2),'ko','Markersize',16,'Linewidth',1,'markerfacecolor','k')
plot([FDSI(1,1)-SEMDSI(1,1),FDSI(1,1)+SEMDSI(1,1)],[FDSI(1,2) FDSI(1,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])
plot([FDSI(1,1) FDSI(1,1)],[FDSI(1,2)-SEMDSI(1,2) FDSI(1,2)+SEMDSI(1,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])

plot(FDSI(2,1),FDSI(2,2),'ko','Markersize',16,'Linewidth',1,'markerfacecolor','k')
plot([FDSI(2,1)-SEMDSI(2,1),FDSI(2,1)+SEMDSI(2,1)],[FDSI(2,2) FDSI(2,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])
plot([FDSI(2,1) FDSI(2,1)],[FDSI(2,2)-SEMDSI(2,2) FDSI(2,2)+SEMDSI(2,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])
text(FDSI(2,1)+0.45,FDSI(2,2)+0.5,'Inexperienced males','color',[.5 .5 .5])

plot(FDSI(3,1),FDSI(3,2),'ko','Markersize',16,'Linewidth',1,'markerfacecolor','k')
plot([FDSI(3,1)-SEMDSI(3,1),FDSI(3,1)+SEMDSI(3,1)],[FDSI(3,2) FDSI(3,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])
plot([FDSI(3,1) FDSI(3,1)],[FDSI(3,2)-SEMDSI(3,2) FDSI(3,2)+SEMDSI(3,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])
text(FDSI(3,1)+0.45,FDSI(3,2)-0.5,'Experienced females','color',[.5 .5 .5])

plot(FDSI(4,1),FDSI(4,2),'ko','Markersize',16,'Linewidth',1,'markerfacecolor','k')
plot([FDSI(4,1)-SEMDSI(4,1),FDSI(4,1)+SEMDSI(4,1)],[FDSI(4,2) FDSI(4,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])
plot([FDSI(4,1) FDSI(4,1)],[FDSI(4,2)-SEMDSI(4,2) FDSI(4,2)+SEMDSI(4,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])
text(FDSI(4,1)+0.45,FDSI(4,2)-0.5,'Experienced males','color',[.5 .5 .5])
axis equal
set(gca,'xlim',[-5 9],'ylim',[-5 9],'LooseInset', [0.01 0.01 0.01 0.01])
xlabel('DSI safety-motives score');ylabel('DSI skills score')
set(findall(gcf,'-property','FontName'),'FontName','Arial','Fontsize',28)
%% CSI motor-tactical-skills score vs. CSI safety-motives score
figure;hold on;
plot([-10 10],[0 0],':','Linewidth',1,'color',[.5 .5 .5])
plot([0 0],[-10 10],':','Linewidth',1,'color',[.5 .5 .5])
plot(F(1,1),F(1,2),'ko','Markersize',16,'Linewidth',1,'markerfacecolor','k')
text(F(1,1)+0.03,F(1,2)-0.03,'Inexperienced females','color',[.5 .5 .5])
text(F(1,1)+0.03,F(1,2)-0.08,['Number of accidents = ' sprintf('%1.2f',nanmean(X(InExpF,37)))],'color',[.5 .5 .5])
plot([F(1,1)-SEM(1,1),F(1,1)+SEM(1,1)],[F(1,2) F(1,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])
plot([F(1,1) F(1,1)],[F(1,2)-SEM(1,2) F(1,2)+SEM(1,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])
plot(F(2,1),F(2,2),'ko','Markersize',16,'Linewidth',1,'markerfacecolor','k')
plot([F(2,1)-SEM(2,1),F(2,1)+SEM(2,1)],[F(2,2) F(2,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])
plot([F(2,1) F(2,1)],[F(2,2)-SEM(2,2) F(2,2)+SEM(2,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])
text(F(2,1)+0.03,F(2,2)-0.03,'Inexperienced males','color',[.5 .5 .5])
text(F(2,1)+0.03,F(2,2)-0.08,['Number of accidents = ' sprintf('%1.2f',nanmean(X(InExpM,37)))],'color',[.5 .5 .5])
plot(F(3,1),F(3,2),'ko','Markersize',16,'Linewidth',1,'markerfacecolor','k')
plot([F(3,1)-SEM(3,1),F(3,1)+SEM(3,1)],[F(3,2) F(3,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])
plot([F(3,1) F(3,1)],[F(3,2)-SEM(3,2) F(3,2)+SEM(3,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])
text(F(3,1)+0.03,F(3,2)-0.03,'Experienced females','color',[.5 .5 .5])
text(F(3,1)+0.03,F(3,2)-0.08,['Number of accidents = ' sprintf('%1.2f',nanmean(X(ExpF,37)))],'color',[.5 .5 .5])
plot(F(4,1),F(4,2),'ko','Markersize',16,'Linewidth',1,'markerfacecolor','k')
plot([F(4,1)-SEM(4,1),F(4,1)+SEM(4,1)],[F(4,2) F(4,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])
plot([F(4,1) F(4,1)],[F(4,2)-SEM(4,2) F(4,2)+SEM(4,2)],'k-','Markersize',16,'Linewidth',2,'markerfacecolor','k','color',[0 0 0])
text(F(4,1)+0.03,F(4,2)-0.03,'Experienced males','color',[.5 .5 .5])
text(F(4,1)+0.03,F(4,2)-0.08,['Number of accidents = ' sprintf('%1.2f',nanmean(X(ExpM,37)))],'color',[.5 .5 .5])
axis equal
set(gca,'xlim',[-0.5 0.5],'ylim',[-0.5 0.5],'looseinset',[0.01 0.01 0.01 0.01])
xlabel('Safety-motives score');ylabel('Motor-tactical-skills score')
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',28)
%% DSI vs Driving km figure (Lajunen & Summala, 1995)
MSDSI=[3.567035334	2.644825258
    3.813876475	3.075635791
    3.656271099	3.029080796
    3.316255667	3.324759669
    3.182570813	3.527280327];
figure;hold on;grid on;box on
plot(1:5,MSDSI(1:5,1),'k-o','Markersize',22,'Linewidth',3)
plot(1:5,MSDSI(1:5,2),'k-s','Markersize',22,'Linewidth',3,'markerfacecolor',[.5 .5 .5])
plot([0 10],polyval(polyfit(1:5,MSDSI(1:5,1)',1),[0 10]),'k--','Linewidth',2)
plot([0 10],polyval(polyfit(1:5,MSDSI(1:5,2)',1),[0 10]),':','Linewidth',2,'color',[.5 .5 .5])
set(gca,'xlim',[0.5 5.5],'xtick',1:5,'xticklabel',{'0-1,000','1,001-5,000','5,001-10,000','10,001-15,000','15,000+'},'LooseInset', [0.01 0.01 0.01 0.01],'ylim',[2.5 4])
xlabel('Driving km');ylabel('Mean score on the scale')
legend('DSI safety-motives score','DSI skills score','location','northeast')
set(findall(gcf,'-property','FontName'),'FontName','Arial','Fontsize',38)
%% CSI scores vs Cycling km
[MS,SS,NN]=deal(NaN(10,2));
for i=1:10
    temp=find(X(:,8)==i);
    NN(i)=length(temp);
    MS(i,:)=nanmean(pc_scores_varimax(temp,:));
    SS(i,:)=nanstd(pc_scores_varimax(temp,:));
end

figure;hold on;grid on
plot(1:10,MS(1:10,1),'k-o','Markersize',22,'Linewidth',3)
plot(1:10,MS(1:10,2),'k-s','Markersize',22,'Linewidth',3,'markerfacecolor',[.5 .5 .5])
plot([0 10],polyval(polyfit(1:10,MS(1:10,1)',1),[0 10]),'k--','Linewidth',2)
plot([0 10],polyval(polyfit(1:10,MS(1:10,2)',1),[0 10]),':','Linewidth',2,'color',[.5 .5 .5])
set(gca,'xlim',[0.5 10.5],'xtick',1:10,'xticklabel',{'0','1-5','6-10','11-30','31-60','61-90','91-120','121-150','151-200','201+'},'LooseInset', [0.01 0.01 0.01 0.05],'ylim',[-0.8 0.6])
xlabel('Cycling km');ylabel('Mean score on the scale')
legend('Safety-motives score','Motor-tactical-skills score','location','northwest')
set(findall(gcf,'-property','FontName'),'FontName','Arial','Fontsize',28)
for i=1:10;text(i,0.65,['N = ' num2str(NN(i))],'color','k','horizontalalignment','center','fontsize',24);end % plot sample sizes on top of figure
pan on
axes('position',[0.38 0.175 .3 .27]);
hold on;box
plot(1:5,MSDSI(1:5,1),'k-o','Markersize',18,'Linewidth',3)
plot(1:5,MSDSI(1:5,2),'k-s','Markersize',18,'Linewidth',3,'markerfacecolor',[.5 .5 .5])
plot([0 10],polyval(polyfit(1:5,MSDSI(1:5,1)',1),[0 10]),'k--','Linewidth',2)
plot([0 10],polyval(polyfit(1:5,MSDSI(1:5,2)',1),[0 10]),':','Linewidth',2,'color',[.5 .5 .5])
set(gca,'xlim',[0.5 5.5],'xtick',1:5,'xticklabel',{'0-1000','1001-5000','5001-10000','10001-15000','15000+'},'LooseInset', [0.01 0.01 0.01 0.01],'ylim',[2.5 4],'fontsize',14)
xlabel('Driving km','fontsize',22);ylabel('Mean score on the scale','fontsize',18)
legend('DSI safety-motives score','DSI skills score','location','southeast','fontsize',14)
%% Figure of correlation coefficients (Oblique, orthogonal, partial)
disp('partial correlations')
[c1,p1]=partialcorr([pc_scores_promax X(:,[3 4 8 9 37])],pc_scores_promax(:,2),'rows','pairwise'); % Correlation matrix partialling out the motor-tactical-skills score
[c2,p2]=partialcorr([pc_scores_promax X(:,[3 4 8 9 37])],pc_scores_promax(:,1),'rows','pairwise'); % Correlation matrix partialling out the safety-motives score
temp=find(isnan(c1));c1(temp)=c2(temp);

figure;grid on;hold on
y=barh([[c_promax(3:end,1) c_varimax(3:end,1) c1(3:end,1)];[c_promax(3:end,2) c_varimax(3:end,2) c1(3:end,2)]]);
plot([-3 3],[5.5 5.5],'k--','Linewidth',3)
y(1).FaceColor=[0 0 0];y(2).FaceColor=[.6 .6 .6];y(3).FaceColor=[.9 .9 .9];
set(gca,'yticklabel',{'Gender - SM','Age - SM', 'Cycling km - SM', 'Cycling frequency - SM', 'Accidents 3Y - SM','Gender - MTS','Age - MTS', 'Cycling km - MTS', 'Cycling frequency - MTS', 'Accidents 3Y - MTS'},'ydir','reverse')
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',28)
legend('Oblique rotation','Orthogonal rotation','Partial correlation','orientation','horizontal','location','Northoutside')
xlabel('Correlation coefficient')
set(gca,'xlim',[-.3 .3],'xtick',-0.3:0.05:0.3,'LooseInset',[0.01 0.01 0.01 0.01],'tickdir','out');
%% Large country analysis (Appendix)
[XC,SDC]=deal(NaN(length(UC),size(X,2))); % mean and SD scores for that country
NC=NaN(length(UC),1); % sample size for that country
LC=NaN(length(UC),17,2); % loadings for that country
TM=NaN(length(UC),6); % What is your primary mode of transport?	1 - car, 2 - motorcycle/moped, 3 - bicycle, 4 - public transport, 5 - walking, 6 - other
pc_scores_varimaxC=NaN(length(UC),2);
[c_varimaxSM_C,c_varimaxMTS_C]=deal(NaN(length(UC),5));
for i=1:length(UC) % loop across the unique countries
    temp=find(strcmp(raw(:,5),UC(i)));
    XC(i,:)=nanmean(X(temp,:),1);
    SDC(i,:)=nanstd(X(temp,:),[],1);
    NC(i)=length(temp); % number of respondents per country
    
    TM(i,:)=100*histc(X(temp,6),1:6)'./sum(histc(X(temp,6),1:6));
    pc_scores_varimaxC(i,:)=mean(pc_scores_varimax(temp,:),1);
    
    [c_varimaxSM_C(i,:)]=corr(pc_scores_varimax(temp,1), X(temp,[3 4 8 9 37]),'rows','pairwise'); % correlation with safety-motives score
    [c_varimaxMTS_C(i,:)]=corr(pc_scores_varimax(temp,2),X(temp,[3 4 8 9 37]),'rows','pairwise'); % correlation with motor-tactical-skills score
    
    r=corr(CSI2(temp,:));
    if sum(sum(isnan(r)))==0
        ldingc=pca(r,2);
        ldingc=rotatefactors(ldingc,'method','promax');
        for i2=1:size(ldingc,2);if mean(ldingc(:,i2))<0;ldingc(:,i2)=-ldingc(:,i2);end;end
        if ldingc(1,1)>ldingc(1,2)
            ldingc=[ldingc(:,2) ldingc(:,1)];
        end
        LC(i,:,:)=ldingc;
    end
end

largecountries=find(NC>=100);
disp('Loadings safety motives, large countries')
disp(LC(largecountries,:,1)')
disp('Loadings motor-tactical skills, large countries')
disp(LC(largecountries,:,2)')

for i=1:length(largecountries)
    disp(' ')
    disp(char(UC(largecountries(i)))) % names of the large countries
    disp(['Sample size = ' sprintf('%1.0f',NC(largecountries(i)))])
    disp(['Percentage males = ' sprintf('%1.1f',100*(XC(largecountries(i),3)-1)) '%'])
    disp(['Mean age = ' sprintf('%1.1f',XC(largecountries(i),4))])
    disp(['SD age = ' sprintf('%1.1f',SDC(largecountries(i),4))])
    disp(['Mean cycling km = ' sprintf('%1.2f',XC(largecountries(i),8))])
    disp(['Mean cycling frequency = ' sprintf('%1.2f',XC(largecountries(i),9))])
    disp(['Mean accidents = ' sprintf('%1.2f',XC(largecountries(i),37))])
    disp(['Mean safety-motives score = ' sprintf('%1.2f',pc_scores_varimaxC(largecountries(i),1))])
    disp(['Mean motor-tactical-skills score = ' sprintf('%1.2f',pc_scores_varimaxC(largecountries(i),2))])
    disp(['Primary tranport mode cycling = '  sprintf('%1.1f',TM(largecountries(i),3))])
    disp(['r SM - Gender = ' sprintf('%1.2f',c_varimaxSM_C(largecountries(i),1)')])
    disp(['r SM - Age = ' sprintf('%1.2f',c_varimaxSM_C(largecountries(i),2)')])
    disp(['r SM - Cycling km = ' sprintf('%1.2f',c_varimaxSM_C(largecountries(i),3)')])
    disp(['r SM - Cycling frequency = ' sprintf('%1.2f',c_varimaxSM_C(largecountries(i),4)')])
    disp(['r SM - Accidents 3Y = ' sprintf('%1.2f',c_varimaxSM_C(largecountries(i),5)')])
    
    disp(['r MTS - Gender = ' sprintf('%1.2f',c_varimaxMTS_C(largecountries(i),1)')])
    disp(['r MTS - Age = ' sprintf('%1.2f',c_varimaxMTS_C(largecountries(i),2)')])
    disp(['r MTS - Cycling km = ' sprintf('%1.2f',c_varimaxMTS_C(largecountries(i),3)')])
    disp(['r MTS - Cycling frequency = ' sprintf('%1.2f',c_varimaxMTS_C(largecountries(i),4)')])
    disp(['r MTS - Accidents 3Y = ' sprintf('%1.2f',c_varimaxMTS_C(largecountries(i),5)')])
end

L1=[LC(largecountries(1),:,1)'  LC(largecountries(1),:,2)'];
L2=[LC(largecountries(2),:,1)'  LC(largecountries(2),:,2)'];
L3=[LC(largecountries(3),:,1)'  LC(largecountries(3),:,2)'];
L4=[LC(largecountries(4),:,1)'  LC(largecountries(4),:,2)'];

disp('Matrix of congruence coefficients')
disp(round([CC(L1,L1) CC(L1,L2) CC(L1,L3) CC(L1,L4)
    CC(L2,L1) CC(L2,L2) CC(L2,L3) CC(L2,L4)
    CC(L3,L1) CC(L3,L2) CC(L3,L3) CC(L3,L4)
    CC(L4,L1) CC(L4,L2) CC(L4,L3) CC(L4,L4)],2));  % congruence coefficients among the four countries
%% Subgroup analysis (Appendix)
[XS,SDS]=deal(NaN(3,size(X,2))); % mean and SD scores for that subgroup
NS=NaN(3,1); % sample size for that subgroup
LS=NaN(3,17,2); % loadings for that subgroup
TM=NaN(3,6); % What is your primary mode of transport?	1 - car, 2 - motorcycle/moped, 3 - bicycle, 4 - public transport, 5 - walking, 6 - other
pc_scores_varimaxS=NaN(3,2);
[c_varimaxSM_S,c_varimaxMTS_S]=deal(NaN(3,5));

for i=1:3 % loop across the subsamples
    if i==1
        temp=find(strcmp(raw(:,2),'Crowdflower1') | strcmp(raw(:,2),'Crowdflower2')  | strcmp(raw(:,2),'facebook'));
    elseif i==2
        temp=find(strcmp(raw(:,2),'TUtraining') | strcmp(raw(:,2),'TUfidelity'));
    elseif i==3
        temp=find(strcmp(raw(:,2),'SWOVtraining'));
    end
    
    XS(i,:)=nanmean(X(temp,:),1);
    SDS(i,:)=nanstd(X(temp,:),[],1);
    NS(i)=length(temp); % number of respondents per country
    TM(i,:)=100*histc(X(temp,6),1:6)'./sum(histc(X(temp,6),1:6));
    pc_scores_varimaxS(i,:)=mean(pc_scores_varimax(temp,:),1);
    
    [c_varimaxSM_S(i,:)]=corr(pc_scores_varimax(temp,1), X(temp,[3 4 8 9 37]),'rows','pairwise'); % correlation with safety-motives score
    [c_varimaxMTS_S(i,:)]=corr(pc_scores_varimax(temp,2),X(temp,[3 4 8 9 37]),'rows','pairwise'); % correlation with motor-tactical-skills score
    
    r=corr(CSI2(temp,:));
    ldingc=pca(r,2);
    ldingc=rotatefactors(ldingc,'method','promax');
    for i2=1:size(ldingc,2);if mean(ldingc(:,i2))<0;ldingc(:,i2)=-ldingc(:,i2);end;end
    if ldingc(1,1)>ldingc(1,2)
        ldingc=[ldingc(:,2) ldingc(:,1)];
    end
    LS(i,:,:)=ldingc;
end

disp('Loadings safety motives, studies')
disp(LS(:,:,1)')
disp('Loadings motor-tactical skills, studies')
disp(LS(:,:,2)')

for i=1:3 % loop across the studies
    disp(' ')
    disp(['Study subgroup number = ' num2str(i)]) % study number
    disp(['Sample size = ' sprintf('%1.0f',NS(i))])
    disp(['Percentage males = ' sprintf('%1.1f',100*(XS(i,3)-1)) '%'])
    disp(['Mean age = ' sprintf('%1.1f',XS(i,4))])
    disp(['SD age = ' sprintf('%1.1f',SDS(i,4))])
    disp(['Mean cycling km = ' sprintf('%1.2f',XS(i,8))])
    disp(['Mean cycling frequency = ' sprintf('%1.2f',XS(i,9))])
    disp(['Mean accidents = ' sprintf('%1.2f',XS(i,37))])
    disp(['Mean safety-motives score = ' sprintf('%1.2f',pc_scores_varimaxS(i,1))])
    disp(['Mean motor-tactical-skills score = ' sprintf('%1.2f',pc_scores_varimaxS(i,2))])
    disp(['Primary tranport mode cycling = '  sprintf('%1.1f',TM(i,3))])
    
    disp(['r SM - Gender = ' sprintf('%1.2f',c_varimaxSM_S(i,1)')])
    disp(['r SM - Age = ' sprintf('%1.2f',c_varimaxSM_S(i,2)')])
    disp(['r SM - Cycling km = ' sprintf('%1.2f',c_varimaxSM_S(i,3)')])
    disp(['r SM - Cycling frequency = ' sprintf('%1.2f',c_varimaxSM_S(i,4)')])
    disp(['r SM - Accidents 3Y = ' sprintf('%1.2f',c_varimaxSM_S(i,5)')])
    
    disp(['r MTS - Gender = ' sprintf('%1.2f',c_varimaxMTS_S(i,1)')])
    disp(['r MTS - Age = ' sprintf('%1.2f',c_varimaxMTS_S(i,2)')])
    disp(['r MTS - Cycling km = ' sprintf('%1.2f',c_varimaxMTS_S(i,3)')])
    disp(['r MTS - Cycling frequency = ' sprintf('%1.2f',c_varimaxMTS_S(i,4)')])
    disp(['r MTS - Accidents 3Y = ' sprintf('%1.2f',c_varimaxMTS_S(i,5)')])
end

L1=[LS(1,:,1)' LS(1,:,2)'];
L2=[LS(2,:,1)' LS(2,:,2)'];
L3=[LS(3,:,1)' LS(3,:,2)'];

disp('Matrix of congruence coefficients')
disp(round(([CC(L1,L1) CC(L1,L2) CC(L1,L3)
             CC(L2,L1) CC(L2,L2) CC(L2,L3)
             CC(L3,L1) CC(L3,L2) CC(L3,L3)]),2)) % congruence coefficients among the three studies
%% Linear regression analysis for predicting the number of cycling accidents in the past three years (Accidents 3Y)
disp('Regression analysis for predicting Accidents')
Xr=[pc_scores_varimax X(:,[3 4 8 9])];
Yr=X(:,37);
Mr=find(sum(isnan(Xr+Yr),2)); % participants with missing data
Yr(Mr)=[];Xr(Mr,:)=[]; % remove participants with missing data
Yr=zscore(Yr);Xr=zscore(Xr);
[Br,BINTr]=regress(Yr,Xr);
st=regstats(Yr, Xr);
[r,p]=corr(Yr,Xr);
disp([round([Br BINTr st.tstat.t(2:end) ]*100)/100,round(1000*st.tstat.pval(2:end))/1000,round(100*r')/100 round(p',3)])
disp(['Number of participants in the regression analysis = ' num2str(length(Yr))])
